==> watcher-5.x-1.1.tar.gz: watcher/js/watcher.js <==
/**
 * Watcher JS
 * By Jakob Persson of Redaktören Reklam & IT
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 */

/**
 * Bind functions
 */
if (Drupal.jsEnabled) {
  $(document).ready( function () {
	   $('.watcher_binder_send_email_status_icon').click( function () { 
	     ajaxToggleEmailNotifications(this, this.href); 
	     return false;
	   });
    $('.watcher_node_toggle_watching_link').click( function () {
      ajaxToggleWatch(this, this.href);
      return false;
    });
  });
}

/********************************************************************
 * EMAIL NOTIFICATION TOGGLE
 ********************************************************************/

/**
 * Handles the AJAX toggle request for email notifications
 * @param {Object} el The element that triggered the request.
 * @param {Object} url The URL to call.
 */
function ajaxToggleEmailNotifications(el, url) {
  toggleEmailIconStatusAni(el, false);
  $.ajax({
  	url: url,
	  type: 'GET',
	  data: { async : 'true' },
	  dataType: 'json',
	  timeout: 4000, //set very high to prevent time outs for users with high latency connections
	  success: function(json){
	    toggleNotificationStatus(el, json);
	   },
	  complete: function(json){
	    toggleEmailIconStatusAni(el, true);
	   }
  });
}

/**
 * Toggle email notification status icon
 * 
 * @param {Object} el The element to modify
 * @param {Object} rdata A JSON object containing the results of the AJAX request
 */
function toggleNotificationStatus(el, rdata) {
  var string_text_enabled = Drupal.settings.watcher.binder_notif_text_enabled;
  var string_text_disabled = Drupal.settings.watcher.binder_notif_text_disabled;
  var string_title_enabled = Drupal.settings.watcher.binder_notif_title_enabled;
  var string_title_disabled = Drupal.settings.watcher.binder_notif_title_disabled;

  if(rdata['status'] == 'enabled') {
	   $(el).empty().append(string_text_enabled).attr('email_status','enabled').attr('title', string_title_enabled);
  } else {
	   $(el).empty().append(string_text_disabled).attr('email_status','disabled').attr('title', string_title_disabled);
  }
}

/**
 * Display an animation to convey to the user that the action has not gone unnoticed
 * 
 * @param {Object} el The element to modify
 */
function toggleEmailIconStatusAni(el, stop) {
  if(stop) {
    $(el).removeClass('watcher_binder_send_email_status_icon_from_disabled_to_enabled'); 
	   $(el).removeClass('watcher_binder_send_email_status_icon_from_enabled_to_disabled');
    if($(el).attr('email_status')=='enabled') {
	     $(el).addClass('watcher_binder_send_email_status_icon_enabled');
  	   $(el).removeClass('watcher_binder_send_email_status_icon_disabled');
	   } else {
	     $(el).addClass('watcher_binder_send_email_status_icon_disabled');
   	  $(el).removeClass('watcher_binder_send_email_status_icon_enabled');
	   }
    return true;  	
  } 
  
		if($(el).attr('email_status')=='enabled') {
	   $(el).addClass('watcher_binder_send_email_status_icon_from_enabled_to_disabled');
  } else {
	  $(el).addClass('watcher_binder_send_email_status_icon_from_disabled_to_enabled');  	
  }
}


/********************************************************************
 * WATCH TOGGLE
 ********************************************************************/

/**
 * Handles the AJAX toggle request for email notifications
 * @param {Object} el The element that triggered the request.
 * @param {Object} url The URL to call.
 */
function ajaxToggleWatch(el, url) {
  // Fade out the element
  $(el).fadeOut("normal");
  
  $.ajax({
  	 url: url,
	   type: 'GET',
	   data: { async : 'true' },
	   dataType: 'json',
	   timeout: 4000, //set very high to prevent time outs for users with high latency connections
	   success: function(json){
	     toggleWatch(el, json);
	   },
    error: function(json){
      $(el).fadeIn("normal");
    }
  });
}

/***
 * Toggle the watching of a node
 */
function toggleWatch(el, rdata) {
  var string_text_enabled = Drupal.settings.watcher.watch_toggle_enabled;
  var string_title_enabled = Drupal.settings.watcher.watch_toggle_enabled_title;
  var string_text_disabled = Drupal.settings.watcher.watch_toggle_disabled;
  var string_title_disabled = Drupal.settings.watcher.watch_toggle_disabled_title;
  var string_watched_posts_link = Drupal.settings.watcher.watch_watched_posts_link;
  
  if(rdata['status'] == 'enabled') {
	   $(el).empty().append(string_text_enabled).attr('title', string_title_enabled).addClass('watcher_node_toggle_watching_link_watched');
    $(el).parent().addClass('watcher_node_watched');
  } else {
	   $(el).empty().append(string_text_disabled).attr('title', string_title_disabled).removeClass('watcher_node_toggle_watching_link_watched');
    $(el).parent().removeClass('watcher_node_watched');
  }
  
  //Append link to user's list of watched posts if it doesn't already exist
  var parent = $(el).parent();
  if($(parent).find('a.watcher_node_help_link_to_binder').length == 0) {
    $(parent).append(string_watched_posts_link);    
  }
 
  
  // Fade in, display the element again
  $(el).fadeIn("normal");
}

==> watcher-5.x-1.2.tar.gz: watcher/js/watcher.js <==
/**
 * Watcher JS
 * By Jakob Persson of Redaktören Reklam & IT
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 */

/**
 * Bind functions
 */
if (Drupal.jsEnabled) {
  $(document).ready( function () {
	   $('.watcher_binder_send_email_status_icon').click( function () { 
	     ajaxToggleEmailNotifications(this, this.href); 
	     return false;
	   });
    $('.watcher_node_toggle_watching_link').click( function () {
      ajaxToggleWatch(this, this.href);
      return false;
    });
  });
}

/********************************************************************
 * EMAIL NOTIFICATION TOGGLE
 ********************************************************************/

/**
 * Handles the AJAX toggle request for email notifications
 * @param {Object} el The element that triggered the request.
 * @param {Object} url The URL to call.
 */
function ajaxToggleEmailNotifications(el, url) {
  toggleEmailIconStatusAni(el, false);
  $.ajax({
  	url: url,
	  type: 'GET',
	  data: { async : 'true' },
	  dataType: 'json',
	  timeout: 4000, //set very high to prevent time outs for users with high latency connections
	  success: function(json){
	    toggleNotificationStatus(el, json);
	   },
	  complete: function(json){
	    toggleEmailIconStatusAni(el, true);
	   }
  });
}

/**
 * Toggle email notification status icon
 * 
 * @param {Object} el The element to modify
 * @param {Object} rdata A JSON object containing the results of the AJAX request
 */
function toggleNotificationStatus(el, rdata) {
  var string_text_enabled = Drupal.settings.watcher.binder_notif_text_enabled;
  var string_text_disabled = Drupal.settings.watcher.binder_notif_text_disabled;
  var string_title_enabled = Drupal.settings.watcher.binder_notif_title_enabled;
  var string_title_disabled = Drupal.settings.watcher.binder_notif_title_disabled;

  if(rdata['status'] == 'enabled') {
	   $(el).empty().append(string_text_enabled).attr('email_status','enabled').attr('title', string_title_enabled);
  } else {
	   $(el).empty().append(string_text_disabled).attr('email_status','disabled').attr('title', string_title_disabled);
  }
}

/**
 * Display an animation to convey to the user that the action has not gone unnoticed
 * 
 * @param {Object} el The element to modify
 */
function toggleEmailIconStatusAni(el, stop) {
  if(stop) {
    $(el).removeClass('watcher_binder_send_email_status_icon_from_disabled_to_enabled'); 
	   $(el).removeClass('watcher_binder_send_email_status_icon_from_enabled_to_disabled');
    if($(el).attr('email_status')=='enabled') {
	     $(el).addClass('watcher_binder_send_email_status_icon_enabled');
  	   $(el).removeClass('watcher_binder_send_email_status_icon_disabled');
	   } else {
	     $(el).addClass('watcher_binder_send_email_status_icon_disabled');
   	  $(el).removeClass('watcher_binder_send_email_status_icon_enabled');
	   }
    return true;  	
  } 
  
		if($(el).attr('email_status')=='enabled') {
	   $(el).addClass('watcher_binder_send_email_status_icon_from_enabled_to_disabled');
  } else {
	  $(el).addClass('watcher_binder_send_email_status_icon_from_disabled_to_enabled');  	
  }
}


/********************************************************************
 * WATCH TOGGLE
 ********************************************************************/

/**
 * Handles the AJAX toggle request for email notifications
 * @param {Object} el The element that triggered the request.
 * @param {Object} url The URL to call.
 */
function ajaxToggleWatch(el, url) {
  // Fade out the element
  $(el).fadeOut("normal");
  
  $.ajax({
  	 url: url,
	   type: 'GET',
	   data: { async : 'true' },
	   dataType: 'json',
	   timeout: 4000, //set very high to prevent time outs for users with high latency connections
	   success: function(json){
	     toggleWatch(el, json);
	   },
    error: function(json){
      $(el).fadeIn("normal");
    }
  });
}

/***
 * Toggle the watching of a node
 */
function toggleWatch(el, rdata) {
  var string_text_enabled = Drupal.settings.watcher.watch_toggle_enabled;
  var string_title_enabled = Drupal.settings.watcher.watch_toggle_enabled_title;
  var string_text_disabled = Drupal.settings.watcher.watch_toggle_disabled;
  var string_title_disabled = Drupal.settings.watcher.watch_toggle_disabled_title;
  var string_watched_posts_link = Drupal.settings.watcher.watch_watched_posts_link;
  
  if(rdata['status'] == 'enabled') {
	   $(el).empty().append(string_text_enabled).attr('title', string_title_enabled).addClass('watcher_node_toggle_watching_link_watched');
    $(el).parent().addClass('watcher_node_watched');
  } else {
	   $(el).empty().append(string_text_disabled).attr('title', string_title_disabled).removeClass('watcher_node_toggle_watching_link_watched');
    $(el).parent().removeClass('watcher_node_watched');
  }
  
  //Append link to user's list of watched posts if it doesn't already exist
  var parent = $(el).parent();
  if($(parent).find('a.watcher_node_help_link_to_binder').length == 0) {
    $(parent).addClass('watcher_node_toggle_watching_link_with_link_to_binder').append(string_watched_posts_link);    
  }
 
  
  // Fade in, display the element again
  $(el).fadeIn("normal");
}
